import { ControllerClass } from '../Controller';
import { ReceiverClass } from '../Receiver';
import { AnyDataboxClass } from '../databox/AnyDataboxClass';
import { AnyChannelClass } from '../channel/AnyChannelClass';
export default class Component {
    /**
     * @description
     * The identifier of the Component from the app config.
     */
    readonly identifier: string;
    /**
     * @description
     * The endpoint name of the Component.
     */
    readonly endpointName: string;
    /**
     * @description
     * The API level of the Component from the app config.
     * It can be undefined if no API level is defined.
     */
    readonly apiLevel: number | undefined;
    constructor(identifier: string, apiLevel: number | undefined);
    toString(): string;
    /**
     * **Can be overridden.**
     * @description
     * Gets once invoked at the start of the server
     * after an instance is created of this Component.
     */
    protected initialize(): Promise<void> | void;
}
export declare type ComponentClass = ControllerClass | ReceiverClass | AnyDataboxClass | AnyChannelClass;
