export declare type ApiLevelSwitch<T> = Record<number, T>;
export declare type ApiLevelSwitchFunction<T> = (apiLevel: number) => T | undefined;
export default class ApiLevelUtils {
    /**
     * Checks if the API level is compatible with the required API level.
     * @param apiLevel
     * @param reqApiLevel
     */
    static apiLevelIsCompatible(apiLevel: number, reqApiLevel: number): boolean;
    /**
     * Build a closure for selecting the API level.
     * The closure will return the correct mapped value with the best compatible API level.
     * If there is no compatible API level, the closure returns undefined.
     * Notice if you always have a 1 in the mapped values as an API level the closure will always return a value.
     * @param apiLevelSwitch
     */
    static createApiLevelSwitcher<T>(apiLevelSwitch: ApiLevelSwitch<T>): ApiLevelSwitchFunction<T>;
    /**
     * Parses the packet API level.
     * @param apiLevel
     */
    static parsePacketApiLevel(apiLevel: any): number | undefined;
}
