export interface ProcessChainConfig {
    /**
     * @description
     * Specifies a process chain.
     * The process chain helps to process the requests synchronously
     * after each other instead of in parallel,
     * even if the request processing contains asynchronous operations.
     * When no object is provided, the process chain is deactivated,
     * and the requests will be processed in parallel and fast as possible.
     * @default null
     */
    processChain?: {
        /**
         * @description
         * Defines the scope of the processChain.
         *
         * When activated, each socket has its own process chain,
         * so the requests of a socket are processed synchronously.
         * But the requests of different sockets are still processed in parallel.
         * Notice that this option has higher memory consumption,
         * but a slow request from one socket doesn't delay the request of another socket.
         *
         * When deactivated, only one process chain exists for the controller,
         * and all sockets' requests are processed synchronously.
         * A slow request will delay all other requests of the controller.
         * @default false
         */
        perSocket?: boolean;
        /**
         * @description
         * The backpressure indicates the length of the process chain.
         * The chain can build up when requests are sent faster than they can be consumed.
         * The limit helps to protect the server against malicious clients to carry out DoS
         * attacks by intentionally filling up the memory with spam messages.
         * When the limit is reached, further requests will be rejected.
         * @default perSocket ? 10 : 1000
         */
        backpressureLimit?: number;
    } | false | null;
}
