import { Middlewares, PreparedMiddlewares } from '../config/definitions/parts/middlewares';
import { AnyFunction } from '../utils/typeUtils';
import { Block } from 'ziron-worker';
import { PreparedEvents } from '../config/definitions/parts/events';
import { BreakChainOn } from "./middlewareDefinition";
export declare type FlowControlledMiddlewareInvoker<T extends AnyFunction> = (...args: Parameters<T>) => Promise<Block | void> | Block | void;
export declare type StandardMiddlewareInvoker<T extends AnyFunction> = (...args: Parameters<T>) => Promise<void>;
export default class MiddlewaresPreparer {
    static prepare(middlewares: Middlewares | undefined, errorEvent: PreparedEvents['error']): PreparedMiddlewares;
    /**
     * Creates an async closure for invoking a flow control middleware.
     * Returns a Block when the action was denied.
     * @param value
     * @param defaultAllow
     * @param errorEvent
     * @param middlewareName
     * @param beforeErrorMsg
     */
    static createFlowControlMiddlewareAsyncSafeInvoker<T extends AnyFunction>(value: T[] | T | undefined, middlewareName: string, defaultAllow: boolean, beforeErrorMsg: string, errorEvent: PreparedEvents['error']): FlowControlledMiddlewareInvoker<T>;
    /**
     * Creates an async closure for invoking a standard middleware.
     * @param value
     * @param chain
     * @param breakChainOn
     * @param beforeErrorMsg
     * @param errorEvent
     */
    static createFlowMiddlewareAsyncSafeInvoker<T extends AnyFunction>(value: T[] | T | undefined, chain: boolean, breakChainOn: BreakChainOn<T> | undefined, beforeErrorMsg: string, errorEvent: PreparedEvents['error']): StandardMiddlewareInvoker<T>;
}
