export declare type AnyFunction = (...args: any[]) => any;
export declare type AnyReadonly = {
    readonly [k: string]: AnyReadonly;
    readonly [i: number]: AnyReadonly;
};
export declare type PartialRecord<K extends keyof any, T> = {
    [P in K]?: T;
};
export interface AnyClass {
    prototype: object;
    new (): any;
    [key: string]: any;
}
export declare type Prototype<T> = T extends AnyClass ? T['prototype'] : never;
export declare type Writable<T> = {
    -readonly [P in keyof T]: T[P];
};
export declare type Primitive = undefined | null | boolean | string | number | Function;
export declare type DeepReadonly<T> = T extends Primitive ? T : T extends Array<infer U> ? DeepReadonlyArray<U> : T extends Map<infer K, infer V> ? DeepReadonlyMap<K, V> : DeepReadonlyObject<T>;
interface DeepReadonlyArray<T> extends ReadonlyArray<DeepReadonly<T>> {
}
interface DeepReadonlyMap<K, V> extends ReadonlyMap<DeepReadonly<K>, DeepReadonly<V>> {
}
declare type DeepReadonlyObject<T> = {
    readonly [K in keyof T]: DeepReadonly<T[K]>;
};
export declare type UnionToIntersection<U> = (U extends any ? (k: U) => void : never) extends ((k: infer I) => void) ? I : never;
declare type UnionForAny<T> = T extends never ? 'A' : 'B';
export declare type IsStrictlyAny<T> = UnionToIntersection<UnionForAny<T>> extends never ? true : false;
export declare type ObjectValues<O extends object> = O[keyof O];
export declare type OptionalObjectKeys<T> = {
    [K in keyof T]-?: undefined extends T[K] ? K : never;
}[keyof T];
export declare type RequiredValue<T> = Exclude<T, undefined>;
export {};
